"""This package contains functions for frequency-domain operations and transformations."""
from . import impl as _impl
from .impl import FFTResult


def thd(signal, fundamental, max_harmonic, during=None):
    """Calculates signal THD

    Parameters
    ----------
    signal : Series
        A Pandas Series with the signal the THD value is to be calculated.
    fundamental : int
        Fundamental frequency of the signal
    max_harmonic : int
        Maximum harmonic (with respect to fundamental) to be taken into consideration in the calculation.
    during : 2-element tuple of float/int or Timedelta
        Period of signal to consider for the calculation.

    Returns
    -------
    thd : float
        Calculated THD value.

    Examples
    --------
    >>> import typhoon.test.signals as signals
    >>> import typhoon.test.harmonic as harmonic

    >>> serie = signals.pandas_sine(1, 60, 1, 1e-6)
    >>> serie += signals.pandas_sine(0.5, 120, 1, 1e-6)

    >>> thd = harmonic.thd(serie, 60, 10)
    """
    return _impl.thd(signal, fundamental, max_harmonic, during)


def frequency_content(signal, max_frequency, during=None):
    """Calculates the list of harmonic components for a signal using FFT.

    Parameters
    ----------
    signal : Series
        A Pandas Series with the signal the harmonic components are to be calculated.
    max_frequency : int
        Maximum frequency to be taken into consideration in the results.
    during : 2-element tuple of float/int or Timedelta
        Period of signal to consider for the calculation.

    Returns
    -------
    result : FFTResult
        Result of the frequency analysis.

    Examples
    --------
    >>> import typhoon.test.signals as signals
    >>> import typhoon.test.harmonic as harmonic

    >>> serie = signals.pandas_sine(amplitude=100, frequency=60) # zeroed signal
    >>> serie += signals.pandas_sine(amplitude=10, frequency=120)
    >>> serie += signals.pandas_sine(amplitude=2, frequency=180)
    >>> content = harmonic.frequency_content(serie, 200)

    >>> plot(content.freqs, content.fft)
    >>> content(60)
    >>> content(10)
    >>> content(2)
    """
    return _impl.frequency_content(signal, max_frequency, during)
